"use strict";

exports.__esModule = true;
exports.formatPieLabel = formatPieLabel;
exports.default = transformProps;

var _core = require("@superset-ui/core");

var _series = require("../utils/series");

var _defaults = require("../defaults");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const percentFormatter = (0, _core.getNumberFormatter)(_core.NumberFormats.PERCENT_2_POINT);

function formatPieLabel({
  params,
  pieLabelType,
  numberFormatter
}) {
  const {
    name = '',
    value,
    percent
  } = params;
  const formattedValue = numberFormatter(value);
  const formattedPercent = percentFormatter(percent / 100);
  if (pieLabelType === 'key') return name;
  if (pieLabelType === 'value') return formattedValue;
  if (pieLabelType === 'percent') return formattedPercent;
  if (pieLabelType === 'key_value') return name + ": " + formattedValue;
  if (pieLabelType === 'key_value_percent') return name + ": " + formattedValue + " (" + formattedPercent + ")";
  if (pieLabelType === 'key_percent') return name + ": " + formattedPercent;
  return name;
}

function transformProps(chartProps) {
  const {
    width,
    height,
    formData,
    queryData
  } = chartProps;
  const data = queryData.data || [];
  const {
    colorScheme,
    donut = false,
    groupby,
    innerRadius = 30,
    labelsOutside = true,
    labelLine = false,
    metric,
    numberFormat,
    outerRadius = 50,
    pieLabelType = 'value',
    showLabels = true,
    showLabelsThreshold = 5,
    showLegend = false
  } = formData;
  const {
    label: metricLabel
  } = (0, _core.convertMetric)(metric);
  const keys = data.map(datum => (0, _series.extractGroupbyLabel)({
    datum,
    groupby
  }));

  const colorFn = _core.CategoricalColorNamespace.getScale(colorScheme);

  const numberFormatter = (0, _core.getNumberFormatter)(numberFormat);
  const transformedData = data.map(datum => {
    const name = (0, _series.extractGroupbyLabel)({
      datum,
      groupby
    });
    return {
      value: datum[metricLabel],
      name,
      itemStyle: {
        color: colorFn(name)
      }
    };
  });

  const formatter = params => {
    if (params.percent < showLabelsThreshold) return '';
    return formatPieLabel({
      params,
      numberFormatter,
      pieLabelType
    });
  };

  const defaultLabel = {
    formatter,
    show: showLabels,
    color: '#000000'
  };
  const echartOptions = {
    grid: _extends({}, _defaults.defaultGrid, {
      top: 30,
      bottom: 30,
      left: 30,
      right: 30
    }),
    tooltip: _extends({}, _defaults.defaultTooltip, {
      trigger: 'item',
      formatter: params => {
        return formatPieLabel({
          params: params,
          numberFormatter,
          pieLabelType: 'key_value_percent'
        });
      }
    }),
    legend: showLegend ? {
      orient: 'horizontal',
      left: 10,
      data: keys
    } : undefined,
    series: [{
      type: 'pie',
      animation: false,
      radius: [(donut ? innerRadius : 0) + "%", outerRadius + "%"],
      center: ['50%', '50%'],
      avoidLabelOverlap: true,
      labelLine: labelLine ? {
        show: true
      } : {
        show: false
      },
      label: labelsOutside ? _extends({}, defaultLabel, {
        position: 'outer',
        alignTo: 'none',
        bleedMargin: 5
      }) : _extends({}, defaultLabel, {
        position: 'inner'
      }),
      emphasis: {
        label: {
          show: true,
          fontWeight: 'bold'
        }
      },
      // @ts-ignore
      data: transformedData
    }]
  };
  return {
    width,
    height,
    echartOptions
  };
}